@@ -8,7 +8,7 @@ summary: >
 # Batch-Channel Normalization
 
 This is a [PyTorch](https://pytorch.org) implementation of Batch-Channel Normalization from the paper
- [Micro-Batch Training with Batch-Channel Normalization and Weight Standardization](https://arxiv.org/abs/1903.10520).
+ [Micro-Batch Training with Batch-Channel Normalization and Weight Standardization](https://papers.labml.ai/paper/1903.10520).
 We also have an [annotated implementation of Weight Standardization](../weight_standardization/index.html).
 
 Batch-Channel Normalization performs batch normalization followed
@@ -63,7 +63,7 @@ class BatchChannelNorm(Module):
         # Channel normalization
         self.channel_norm = ChannelNorm(channels, groups, eps)
 
-    def __call__(self, x):
+    def forward(self, x):
         x = self.batch_norm(x)
         return self.channel_norm(x)
 
@@ -113,7 +113,7 @@ class EstimatedBatchNorm(Module):
         self.register_buffer('exp_mean', torch.zeros(channels))
         self.register_buffer('exp_var', torch.ones(channels))
 
-    def __call__(self, x: torch.Tensor):
+    def forward(self, x: torch.Tensor):
         """
         `x` is a tensor of shape `[batch_size, channels, *]`.
         `*` denotes any number of (possibly 0) dimensions.
@@ -195,7 +195,7 @@ class ChannelNorm(Module):
             self.scale = nn.Parameter(torch.ones(groups))
             self.shift = nn.Parameter(torch.zeros(groups))
 
-    def __call__(self, x: torch.Tensor):
+    def forward(self, x: torch.Tensor):
         """
         `x` is a tensor of shape `[batch_size, channels, *]`.
         `*` denotes any number of (possibly 0) dimensions.
