@@ -7,6 +7,9 @@ summary: This experiment trains a small switch transformer on tiny Shakespeare d
 # Switch Transformer Experiment
 
 This is an annotated PyTorch experiment to train a switch transformer.
+
+[![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/labmlai/annotated_deep_learning_paper_implementations/blob/master/labml_nn/transformers/switch/experiment.ipynb)
+[![View Run](https://img.shields.io/badge/labml-experiment-brightgreen)](https://app.labml.ai/run/353770ce177c11ecaa5fb74452424f46)
 """
 
 import torch
@@ -119,6 +122,8 @@ class Configs(NLPAutoRegressionConfigs):
         route_prob = route_prob / total
         # Load balancing loss
         # $$\mathscr{L} = N \sum_{i=1}^N f_i \cdot P_i$$
+        # $\mathscr{L}$ is the loss for a single layer and here we are
+        # taking the sum of losses across all layers.
         load_balancing_loss = self.n_experts * (route_frac * route_prob).sum()
 
         # Track stats
@@ -206,7 +211,6 @@ def main():
                         'prompt_separator': '',
 
                         'transformer': 'switch_transformer',
-                        'is_scale_prob': False,
                         'n_experts': 4,
 
                         'drop_tokens': True,
